# Streaminghub Curator

A web interface to package bio-signal datasets with DFDS metadata, which enables streaming their data into computational workflows with minimal effort.

## Usage Instructions

### Define Dataset and Files

### Extract Metadata from Paths/Names (Examples)

```plaintext
# ADHD_SIN dataset (e.g., 003ADHD_AV_103.csv)
(?P<subject>\d+)ADHD_AV_(?P<noise>0|5|10|15|20|25)(?P<task>\d+).csv
```

### Define Streams

### Assign File Attributes to Stream Fields

### Export Dataset

You just created a streamable dataset, cheers! Time to congratulate yourself with a cup of coffee.
